@@ -263,6 +263,13 @@ class API(object):
         allowed_param = ['id', 'user_id', 'screen_name']
     )
     
+    """ users/show """
+    get_user2 = bind_api(
+        path = '2/users/show.json',
+        payload_type = 'user',
+        allowed_param = ['uid', 'screen_name']
+    )
+    
     """ Get the authenticated user """
     def me(self):
         return self.get_user(screen_name=self.auth.get_username())
@@ -278,14 +285,15 @@ class API(object):
     """ statuses/friends """
     friends = bind_api(
         path = '/statuses/friends.json',
-        payload_type = 'user', payload_list = True,
+        payload_type = 'userlist',
         allowed_param = ['id', 'user_id', 'screen_name', 'page', 'cursor']
     )
 
     """ statuses/followers """
     followers = bind_api(
         path = '/statuses/followers.json',
-        payload_type = 'user', payload_list = True,
+        #payload_type = 'user', payload_list = True,
+        payload_type = 'userlist',
         allowed_param = ['id', 'user_id', 'screen_name', 'page', 'cursor']
     )
 
